package fr.insa.clavardator.chat;

import fr.insa.clavardator.users.User;

import java.io.File;
import java.io.FileInputStream;
import java.io.IOException;

public class FileMessage extends Message {
	public static final long MAX_FILE_SIZE = 20 * 1024 * 1024; // 20 Mo

	private final byte[] rawFile;
	private final String fileName;

	public FileMessage(User sender, User recipient, String filePath, String text) throws IOException {
		super(sender, recipient, text);

		File file = new File(filePath);
		if (!file.exists())
			throw new IOException("The file does not exist");
		if (!file.canRead())
			throw new IOException("The file is not readable");
		if (!file.isFile())
			throw new IOException("The path does not lead to a file");
		if (file.length() > MAX_FILE_SIZE)
			throw new IOException("The file is too large");

		fileName = file.getName();

		FileInputStream stream = new FileInputStream(file);
		rawFile = stream.readAllBytes();
	}

	public byte[] getRawFile() {
		return rawFile;
	}

	public String getFileName() {
		return fileName;
	}
}