package fr.insa.clavardator.network;

import fr.insa.clavardator.chat.Message;
import fr.insa.clavardator.util.ErrorHandler;

import java.io.IOException;
import java.io.ObjectOutputStream;
import java.io.Serializable;
import java.net.InetAddress;
import java.net.Socket;

public class PeerConnection {
	public static final short PORT = 31598;

	private Socket socket;

	public PeerConnection(InetAddress ipAddr) {
		try {
			socket = new Socket(ipAddr, PORT);
		} catch (IOException e) {
			ErrorHandler.getInstance().notifyError(e);
		}
	}

	/**
	 * @param message
	 * @param callback
	 */
	public void sendMessage(Message message, MessageSentCallback callback) {
		Sender sender = new Sender(message, callback);
		sender.start();
	}

	public void receiveMessage(MessageReceivedCallback callback) {
		Receiver receiver = new Receiver(callback);
		receiver.start();
	}


	private class Sender extends Thread {
		Serializable message;
		MessageSentCallback callback;

		/**
		 * Constructs and starts a thread that sends a message using the socket of the outer class
		 * @param messsage The message to send
		 * @param callback The function to call once finished
		 */
		public Sender(Serializable messsage, MessageSentCallback callback) {
			this.message = messsage;
			this.callback = callback;
		}

		@Override
		synchronized public void run() {
			try {
				// TODO: store the oos in Peer connection?
				ObjectOutputStream oos = new ObjectOutputStream(socket.getOutputStream());
				oos.writeObject(message);
			} catch (IOException e) {
				ErrorHandler.getInstance().notifyError(e);
			}
			callback.onMessageSent();
		}
	}

	private class Receiver extends Thread {
		MessageReceivedCallback callback;

		public Receiver(MessageReceivedCallback callback) {
			this.callback = callback;
		}

		@Override
		public void run() {
			//TODO
//			callback.onMessageReceived();
		}
	}


		public interface MessageReceivedCallback {
		void onMessageReceived(Message msg);
	}
	public interface MessageSentCallback {
		void onMessageSent();
	}

}
