package fr.insa.clavardator.ui.chat;

import fr.insa.clavardator.chat.Message;
import fr.insa.clavardator.ui.ButtonPressEvent;
import fr.insa.clavardator.ui.NoSelectionModel;
import fr.insa.clavardator.users.CurrentUser;
import fr.insa.clavardator.users.PeerUser;
import javafx.collections.FXCollections;
import javafx.collections.ObservableList;
import javafx.fxml.FXML;
import javafx.fxml.Initializable;
import javafx.scene.control.ListView;

import java.net.URL;
import java.util.ResourceBundle;

public class ChatController implements Initializable {

	@FXML
	private ListView<Message> messageList;
	@FXML
	private ChatFooterController chatFooterController;
	@FXML
	private ChatHeaderController chatHeaderController;

	private CurrentUser currentUser;
	private PeerUser remoteUser;

	public void addAttachmentListener(ButtonPressEvent listener) {
		chatFooterController.addAttachmentListener(listener);
	}

	public void addSendListener(ButtonPressEvent listener) {
		chatFooterController.addSendListener(listener);
	}

	public void addEditListener(ButtonPressEvent listener) {
		chatHeaderController.addEditListener(listener);
	}


	public void setCurrentUser(CurrentUser currentUser) {
		this.currentUser = currentUser;
	}

	public void setRemoteUser(PeerUser remoteUser) {
		this.remoteUser = remoteUser;
		loadMessageList();
	}

	private void loadMessageList() {
		ObservableList<Message> messages = FXCollections.observableArrayList(
				new Message(remoteUser, currentUser, "Messsssage 1"),
				new Message(remoteUser, currentUser, "Messsssage 2"),
				new Message(currentUser, remoteUser, "Messsssage 3"),
				new Message(remoteUser, currentUser, "Messsssage 4")
		);
		messageList.setItems(messages);
		messageList.scrollTo(messageList.getItems().size() - 1);
	}

	@Override
	public void initialize(URL url, ResourceBundle rb) {
		messageList.setItems(null);
		messageList.setSelectionModel(new NoSelectionModel<Message>());
		messageList.setCellFactory(listView -> new MessageListItemCell());
	}

}