package fr.insa.clavardator.ui.users;

import fr.insa.clavardator.ui.ButtonPressEvent;
import fr.insa.clavardator.ui.UserSelectedEvent;
import fr.insa.clavardator.users.ActiveUser;
import fr.insa.clavardator.users.PeerUser;
import fr.insa.clavardator.users.User;
import javafx.collections.FXCollections;
import javafx.collections.ObservableList;
import javafx.fxml.FXML;
import javafx.fxml.Initializable;
import javafx.scene.control.ListView;

import java.net.InetAddress;
import java.net.URL;
import java.net.UnknownHostException;
import java.util.ArrayList;
import java.util.List;
import java.util.ResourceBundle;

public class UserListController implements Initializable {

	final private List<ButtonPressEvent> refreshUserListeners;
	final private List<UserSelectedEvent> userSelectedListeners;
	@FXML
	private ListView<User> userList;

	public UserListController() {
		super();
		refreshUserListeners = new ArrayList<>();
		userSelectedListeners = new ArrayList<>();
	}

	public void addRefreshUserListener(ButtonPressEvent listener) {
		refreshUserListeners.add(listener);
	}

	public void addUserSelectedListener(UserSelectedEvent listener) {
		userSelectedListeners.add(listener);
	}

	public void onRefreshUserListPress() {
		refreshUserListeners.forEach(ButtonPressEvent::onPress);
	}

	private void onUserSelected(@org.jetbrains.annotations.NotNull User user) {
		final User currentSelectedUser = userList.getSelectionModel().getSelectedItem();
		if (!user.equals(currentSelectedUser)) {
			userList.getSelectionModel().select(user);
			userSelectedListeners.forEach(l -> l.onSelected(user));
		}
	}

	@Override
	public void initialize(URL url, ResourceBundle rb) {
		ObservableList<User> activeList = null;
		try {
			activeList = FXCollections.observableArrayList(
					new PeerUser("Dodo0"),
					new PeerUser("Dodo3"),
					new PeerUser("Dodo2"),
					new ActiveUser("Coucou0", InetAddress.getLocalHost()),
					new ActiveUser("Coucou1", InetAddress.getLocalHost()),
					new ActiveUser("Coucou3", InetAddress.getLocalHost()),
					new PeerUser("Dodo1"),
					new ActiveUser("Coucou2", InetAddress.getLocalHost())
			);
		} catch (UnknownHostException e) {
			e.printStackTrace();
		}
		if (activeList != null) {
			activeList.sort(null);
		}
		userList.setItems(activeList);
		userList.setCellFactory(listView -> {
			final UserListItemCell cell = new UserListItemCell();
			cell.setOnUserSelectedListener(this::onUserSelected);
			return cell;
		});
	}
}